==> prestashop_1.4.9.0.zip: prestashop/modules/blockcustomerprivacy/de.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{blockcustomerprivacy}prestashop>blockcustomerprivacy_0cec62d1bea02fbb1484d55d14f493dd'] = 'Block Kunde Datenschutz';
$_MODULE['<{blockcustomerprivacy}prestashop>blockcustomerprivacy_3a32ec2dbd8d955f6240d95d6004557c'] = 'Fügt einen Block, um eine Nachricht zu Kundendaten Privatsphäre anzuzeigen.';
$_MODULE['<{blockcustomerprivacy}prestashop>blockcustomerprivacy_20015706a8cbd457cbb6ea3e7d5dc9b3'] = 'Konfiguration aktualisiert';
$_MODULE['<{blockcustomerprivacy}prestashop>blockcustomerprivacy_b75fe4f32f17eb695f145704a8909146'] = 'Nachricht für Kunden des Datenschutzes';
$_MODULE['<{blockcustomerprivacy}prestashop>blockcustomerprivacy_03e6791c07164957bb87bfad5030f846'] = 'Nachricht, dass in der Account-Erstellung Form angezeigt werden.';
$_MODULE['<{blockcustomerprivacy}prestashop>blockcustomerprivacy_2d4e74ab9c95452f5948cd959d186b6d'] = 'Tipps: Denken Sie daran, dass, wenn der Text zu lang, um direkt in das Formular geschrieben werden, können Sie einen Link zu einer Ihrer Seiten über das CMS Register erstellt haben.';
$_MODULE['<{blockcustomerprivacy}prestashop>blockcustomerprivacy_c9cc8cce247e49bae79f15173ce97354'] = 'Sparen';
$_MODULE['<{blockcustomerprivacy}prestashop>blockcustomerprivacy_ffeb523df77567c7fad7faf8af5f7e46'] = 'Bitte stimmen Sie mit dem Kunden des Datenschutzes, indem Sie das Kontrollkästchen unten.';
$_MODULE['<{blockcustomerprivacy}prestashop>blockcustomerprivacy_fb0440f9ca32a8b49eded51b09e70821'] = 'Kunden Datenschutz';

==> prestashop_1.4.11.1.zip: prestashop/modules/blockcustomerprivacy/de.php <==
<?php

global $_MODULE;
$_MODULE = array();

$_MODULE['<{blockcustomerprivacy}prestashop>blockcustomerprivacy_0cec62d1bea02fbb1484d55d14f493dd'] = 'Block Kunde Datenschutz';
$_MODULE['<{blockcustomerprivacy}prestashop>blockcustomerprivacy_3a32ec2dbd8d955f6240d95d6004557c'] = 'Fügt einen Block, um eine Nachricht zu Kundendaten Privatsphäre anzuzeigen.';
$_MODULE['<{blockcustomerprivacy}prestashop>blockcustomerprivacy_20015706a8cbd457cbb6ea3e7d5dc9b3'] = 'Konfiguration aktualisiert';
$_MODULE['<{blockcustomerprivacy}prestashop>blockcustomerprivacy_b75fe4f32f17eb695f145704a8909146'] = 'Nachricht für Kunden des Datenschutzes';
$_MODULE['<{blockcustomerprivacy}prestashop>blockcustomerprivacy_03e6791c07164957bb87bfad5030f846'] = 'Nachricht, dass in der Account-Erstellung Form angezeigt werden.';
$_MODULE['<{blockcustomerprivacy}prestashop>blockcustomerprivacy_2d4e74ab9c95452f5948cd959d186b6d'] = 'Tipps: Denken Sie daran, dass, wenn der Text zu lang, um direkt in das Formular geschrieben werden, können Sie einen Link zu einer Ihrer Seiten über das CMS Register erstellt haben.';
$_MODULE['<{blockcustomerprivacy}prestashop>blockcustomerprivacy_c9cc8cce247e49bae79f15173ce97354'] = 'Speichern';
$_MODULE['<{blockcustomerprivacy}prestashop>blockcustomerprivacy_ffeb523df77567c7fad7faf8af5f7e46'] = 'Bitte stimmen Sie mit dem Kunden des Datenschutzes, indem Sie das Kontrollkästchen unten.';
$_MODULE['<{blockcustomerprivacy}prestashop>blockcustomerprivacy_fb0440f9ca32a8b49eded51b09e70821'] = 'Kunden-Datenschutz';
